# -*- coding: utf-8 -*-

"""Top-level package for  Numerical_Z."""

__author__ = """Antoine Tavant"""
__email__ = 'antoinetavant@hotmail.fr'
__version__ = '0.1.0'


from numerical_z.numerical_z import  NumericZ
from numerical_z.plasma import PlasmaParameters
from numerical_z.langmuir import  epsLangmuir_Maxw, epsLangmuirGene
